%global provider github
%global provider_tld com
%global project Calysto
%global repo metakernel
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}

%global commit0 c1732a2c10d0838ef36e0caac3924d6f582c0070
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global date 20201110

Name:		python-metakernel
#		The python and echo subpackages have their own version
#		and release numbers - update below in each package section
#		Running rpmdev-bumpspec on this specfile will update all the
#		release tags automatically
Version:	0.27.5
Release:	%mkrel 2
%global pkgversion %{version}
%global pkgrelease %{release}
Summary:	Metakernel for Jupyter
Group:          Development/Python

License:	BSD
URL:		https://github.com/Calysto/metakernel
Source0:	https://github.com/Calysto/metakernel/archive/%{version}/%{name}-%{version}.tar.gz

BuildArch:	noarch
BuildRequires:	python3-devel
BuildRequires:	python3-ipykernel
BuildRequires:	python3-pexpect >= 4.2
#		For testing:
BuildRequires:	python3-pytest
BuildRequires:	python3-requests
BuildRequires:	python3-ipyparallel >= 6.2.5
BuildRequires:	python3-jedi
BuildRequires:  ipyparallel >= 6.2.5
BuildRequires:	man
# needed for man sleep in test 
BuildRequires:  coreutils-doc
#		For documentation
BuildRequires:	python3-sphinx
BuildRequires:	python3-sphinx-bootstrap-theme
BuildRequires:	python3-numpydoc
BuildRequires:	python3-recommonmark

%description
A Jupyter/IPython kernel template which includes core magic functions
(including help, command and file path completion, parallel and
distributed processing, downloads, and much more).

%package -n python3-metakernel
Summary:	Metakernel for Jupyter
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel}
Requires:	python3-ipykernel
Requires:	python3-pexpect >= 4.2
Obsoletes:	python3-metakernel-bash < 0.19.1-24

%description -n python3-metakernel
A Jupyter/IPython kernel template which includes core magic functions
(including help, command and file path completion, parallel and
distributed processing, downloads, and much more).

%package -n python3-metakernel-tests
Summary:	Tests for python3-metakernel
Group:          Development/Python
%{?python_provide:%python_provide python3-metakernel-tests}
Requires:	python3-metakernel = %{version}-%{release}
Requires:	python3-metakernel-python
Requires:	python3-pytest
Requires:	python3-requests
Requires:	python3-ipyparallel
Requires:	python3-jedi
Requires:	man

%description -n python3-metakernel-tests
This package contains the tests of python3-metakernel.

%package doc
Summary:	Documentation for python-metakernel
BuildArch:      noarch
Group:          Documentation

%description doc
This package contains the documentation of python-metakernel.

%package -n python3-metakernel-python
Version:	0.19.1
Release:	%mkrel 36
Summary:	A Python kernel for Jupyter/IPython
%{?python_provide:%python_provide python3-metakernel-python}
Requires:	python3-metakernel = %{pkgversion}-%{pkgrelease}
Requires:	python3-jedi
Group:          Development/Python

%description -n python3-metakernel-python
A Python kernel for Jupyter/IPython, based on MetaKernel.

%package -n python3-metakernel-echo
Version:	0.19.1
Release:	%mkrel 36
Summary:	A simple echo kernel for Jupyter/IPython
%{?python_provide:%python_provide python3-metakernel-echo}
Requires:	python3-metakernel = %{pkgversion}-%{pkgrelease}
Group:          Development/Python

%description -n python3-metakernel-echo
A simple echo kernel for Jupyter/IPython, based on MetaKernel.

%prep
%autosetup -p1 -n metakernel-%{pkgversion}

%build
%py3_build

pushd metakernel_python
%py3_build
popd

pushd metakernel_echo
%py3_build
popd

pushd docs
PYTHONPATH=.. make html SPHINXBUILD=sphinx-build-3
rm -f _build/html/.buildinfo
popd

%install
%py3_install

pushd metakernel_python
%py3_install
popd

pushd metakernel_echo
%py3_install
popd

for f in tests/test_expect.py; do
  sed '/\/usr\/bin\/env/d' -i %{buildroot}%{python3_sitelib}/metakernel/${f}
done

PYTHONPATH=metakernel_python \
  python3 -m metakernel_python install --name python3-metakernel-python \
  --prefix %{buildroot}%{_prefix}
PYTHONPATH=metakernel_echo \
  python3 -m metakernel_echo install --name python3-metakernel-echo \
  --prefix %{buildroot}%{_prefix}

%check
export LC_ALL=C
export LANG=C
export LANGUAGE=C
PYTHONPATH=metakernel_python ipcluster start -n=3 &
pid=$!
%if %{mageia} >= 8
# The REPLWrapTestCase.test_python test fails with readline version 8.1
# https://github.com/Calysto/metakernel/issues/228
pytest-3 -v metakernel -k 'not REPLWrapTestCase or not test_python'
%else
pytest-3 -v metakernel
%endif
ipcluster stop
wait $pid
rm -f ${HOME}/.ipython/metakernel/magics/__pycache__/*.pyc

%files -n python3-metakernel
%license LICENSE.txt
%doc README.rst
%{python3_sitelib}/metakernel-*.egg-info
%dir %{python3_sitelib}/metakernel
%{python3_sitelib}/metakernel/*.py
%{python3_sitelib}/metakernel/__pycache__
%{python3_sitelib}/metakernel/images
%dir %{python3_sitelib}/metakernel/magics
%{python3_sitelib}/metakernel/magics/*.py
%{python3_sitelib}/metakernel/magics/__pycache__
%{python3_sitelib}/metakernel/utils

%files -n python3-metakernel-tests
%{python3_sitelib}/metakernel/tests
%{python3_sitelib}/metakernel/magics/tests

%files doc
%license LICENSE.txt
%doc docs/_build/html

%files -n python3-metakernel-python
%{python3_sitelib}/metakernel_python-*.egg-info
%{python3_sitelib}/metakernel_python.py
%{python3_sitelib}/__pycache__/metakernel_python.*
%{_datadir}/jupyter/kernels/python3-metakernel-python

%files -n python3-metakernel-echo
%{python3_sitelib}/metakernel_echo-*.egg-info
%{python3_sitelib}/metakernel_echo.py
%{python3_sitelib}/__pycache__/metakernel_echo.*
%{_datadir}/jupyter/kernels/python3-metakernel-echo


%changelog
* Tue Jan 26 2021 daviddavid <daviddavid> 0.27.5-2.mga8
+ Revision: 1673371
- disable test failing due to new readline 8.1

* Fri Dec 18 2020 joequant <joequant> 0.27.5-1.mga8
+ Revision: 1660598
- update to 0.27.5

* Tue Aug 25 2020 joequant <joequant> 0.26.1-1.mga8
+ Revision: 1618817
- update to 0.26.1

* Mon Aug 24 2020 joequant <joequant> 0.26.0-2.mga8
+ Revision: 1618279
- rebuild to include exec patch
- use previous metakernel build
- add new patches for 0.26.0

* Sun Aug 23 2020 joequant <joequant> 0.26.0-1.mga8
+ Revision: 1618097
- update to 0.26.0

* Sat Aug 22 2020 joequant <joequant> 0.26.0-0.20200822gita22b9fb.1.mga8
+ Revision: 1618010
- fix patch for eval
- redo eval patch
- fix retval patch
- add eval patch from dev build

* Sat Aug 22 2020 joequant <joequant> 0.26.0-0.20200820gita22b9fb.mga8
+ Revision: 1617924
- update to latest git version

* Thu Apr 30 2020 joequant <joequant> 0.24.4-1.mga8
+ Revision: 1573530
- fix dep comment
- add coreutils-doc to pass tests
- imported package python-metakernel

